@@ -19,7 +19,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-# $Id: FileHandle.pm,v 1.3 2001/07/04 10:32:04 rich Exp $
+# $Id: FileHandle.pm,v 1.4 2001/07/25 19:18:23 rich Exp $
 
 =pod
 
@@ -120,6 +120,11 @@ sub status
 	$atime, $mtime, $ctime, $blksize, $blocks)
       = lstat $self->{_pathname};
 
+    # If the file has been removed since we created this
+    # handle, then $dev will be undefined. Return dummy status
+    # information.
+    return ("f", 0000, 1, "-", "-", 0, 0) unless $dev;
+
     # Generate printable user/group.
     my $user = getpwuid ($uid) || "-";
     my $group = getgrgid ($gid) || "-";
